%% Initialization
close all
clear all
clc

waveSc = dlmread('waveconditions_Sc.txt');

dataSc = dlmread('uh_Sc.txt');

[m, n] = size(waveSc);

%Povt = zeros(m,1); 
Vovt = zeros(m,1); 

Vovt_Hm02 = zeros(m,1);

% flow depth proposed by Trung
hA_Tr = zeros(m,1);

uA_Tr = zeros(m,1);

hA_Hm0_Sc = zeros(m,1);

uA_gHm0_Sc = zeros(m,1);

RuRc_Hm0 = zeros(m,1);


%% constants
% acceleration due to gravity [m/s2]
g = 9.81; 
c1 = 4.75; c2 = 1.65; % probabilistic design

% landward-side slope
tan_alphaSc = 1/6; sin_alphaSc = sin(atan(1/6)); cos_alphaSc = cos(atan(1/6));

% coefficient derived from regression analysis of van Gent's data
cAh = 1.097; cAu = 0.8917;

cT = 1.15; % Tm = Tp/1.15 assumption

%% calculations
for i = 1:m
        % wave steepness
        s0 = 2*pi/g*waveSc(i,3)/((waveSc(i,4))^2);
        % surf similarity parameter xi_0
        xi0 = tan_alphaSc/sqrt(s0);
        % 2% wave run-up
        Ru2per = c2*xi0*waveSc(i,3);
        Povt = exp(-((sqrt(-log(0.02))*waveSc(i,2)/Ru2per)^2));
        q = sqrt(g*((waveSc(i,3))^3))*0.067/sqrt(tan_alphaSc)*xi0*exp(-c1*waveSc(i,2)/waveSc(i,3)/xi0);
        a = 0.84*waveSc(i,5)/cT*q/Povt;
        
        Vovt(i) = a*(-log(0.02/Povt))^(4/3);
        
        Vovt_Hm02(i) = Vovt(i)/((waveSc(i,3))^2);
        
        hA_Tr(i) = Vovt(i)*sin_alphaSc/(Ru2per - waveSc(i,2))/waveSc(i,3);
        
        uA_Tr(i) = cos_alphaSc/waveSc(i,3)*sqrt(Vovt(i)/sin_alphaSc);
        
        % hA,2% / Hm0  and uA,2% / (gHm0)^0.5 of Flowdike
        hA_Hm0_Sc(i) = dataSc(i,1)/waveSc(i,3);
        
        uA_gHm0_Sc(i) = dataSc(i,5)/sqrt(g*waveSc(i,3)); 
     
        
end

% V2%/(Hs)^2 measured by Schutrrumpf
VA_Hm02 = dataSc(:,7);

% creating data for linear regression analysis
result = [hA_Hm0_Sc'; hA_Tr'; uA_gHm0_Sc'; uA_Tr'; VA_Hm02';  Vovt_Hm02']';
save result_Sc.txt result -ASCII;

% figure 1 showing flow depth
 figure1 = figure('Name','Flow depth hA2%/Hm0 of Schuttrumpf vs. computation');
    set(figure1,'PaperUnits','points');

    xSize = 245; ySize = 180;

    % additional coordinates to locate the figure on A4-paper
    xLeft = (597-xSize)/2; yTop = (845-ySize)/2;

    % set the position and size of the figure on the paper to the desired
    % values
    set(figure1,'PaperPosition', [xLeft yTop xSize ySize]);

    % reset the size and position of the figure window on the computer screen
    set(figure1,'Position', [xLeft yTop xSize*2 ySize*2]);

    x = 45/xSize; y = 40/ySize; 

    % Figure dimensions are 142 pt wide and 106.3 pt high
    width = 180/xSize; height = 127/ySize;

    % Create axes
    axes1 = axes('Parent', figure1, 'position', [x y width height]);
    set(axes1,'XMinorGrid','off');

    % Create xlabel
    xlabel('h_{A,2%} / H_{m0} computation');
    % Create ylabel
    ylabel('h_{A,2%} / H_{m0} measurement');

    % X-limits of the axes
    %xlim(axes1,[0.05 1]);
    % Y-limits of the axes
    %ylim(axes1,[0.05 1]);
    
    box(axes1,'on');
    hold(axes1,'all');
    
% Flowdike test
plot1 = plot(Vovt_Hm02,  VA_Hm02,'Parent',axes1,'LineStyle','none','Color',[0 0 0]);
set(plot1,'Marker','o','DisplayName','Schuttrumpf');
% plot2 = plot(hA_Tr(13:24),  hA_Hm0_FD(13:24),'Parent',axes1,'LineStyle','none','Color',[0 0 0]);
% set(plot2,'Marker','square','DisplayName','FD06');

plot3 = plot([0 1], [0 1],'Parent',axes1);
set(plot3,'Color','Black');
% 
% 
% % Create legend
%     legend1 = legend(axes1,'Schuttrumpf');
%     set(legend1,'Location','EastOutside');
% 
% % print figure as an eps file    
%     %print('-depsc','-tiff','-r600', 'hA2_ScvsTrung'); 
%     
%  % figure 2 linear relation
% figure2 = figure('Name','Flow velocity uA2% of Schuttrumpf vs. Trung');
%     set(figure2,'PaperUnits','points');
% 
%     % set the position and size of the figure on the paper to the desired
%     % values
%     set(figure2,'PaperPosition', [xLeft yTop xSize ySize]);
% 
%     % reset the size and position of the figure window on the computer screen
%     set(figure2,'Position', [xLeft yTop xSize*2 ySize*2]);
% 
%     % Create axes
%     axes2 = axes('Parent', figure2, 'position', [x y width height]);
%     set(axes2,'XMinorGrid','off');
% 
%     % Create xlabel
%     xlabel('u_{A,2%}/(gH_{m0})^{0.5} computation');
%     % Create ylabel
%     ylabel('u_{A,2%}/(gH_{m0})^{0.5} measurement');
% 
%     % X-limits of the axes
%     %xlim(axes2,[0.2 4]);
%     % Y-limits of the axes
%     %ylim(axes2,[0.2 4]);
%     
%     box(axes2,'on');
%     hold(axes2,'all');
%     
%     % Flowdike test
% plot4 = plot(uA_Tr,  uA_gHm0_Sc,'Parent',axes2,'LineStyle','none','Color',[0 0 0]);
% set(plot4,'Marker','o','DisplayName','Schuttrumpf');
% % plot5 = plot(uA_Tr(13:24),  uA_gHm0_FD(13:24),'Parent',axes2,'LineStyle','none','Color',[0 0 0]);
% % set(plot5,'Marker','square','DisplayName','FD06');
% 
% plot6 = plot([0 4], [0 4],'Parent',axes2);
% set(plot6,'Color','Black');
% 
% 
% % Create legend
%     legend2 = legend(axes2,'Schuttrumpf');
%     set(legend2,'Location','EastOutside');
% 
% % print figure as an eps file    
%     %print('-depsc','-tiff','-r600', 'uA2_ScvsTrung'); 
    