%% Initialization
close all
clear all
clc

%waveFD = dlmread('waveconditions_FD.txt');

%dataFD = dlmread('uh_FD.txt');

Hm0 = 1.5; % wave height
Tp = 6; % peak period
Tm = Tp/1.15; 
Tm10 = Tp/1.1;

% mean overtopping discharges used for the simulator [m3/m]
q = [0.01 0.02 0.04 0.08 0.1];
n = length(q);

% overtopping volumes used for hydraulic measurement with the simulator
V = [0.5 1 1.5 2 2.5 3 3.5 4 4.5 5];
m = length(V);

    PV = zeros(m,n);
    
    Povx = zeros(m,n);
    
    Rux = zeros(m,n);
    
    hA2_Hm0 = zeros(m,n);
    
    uA2_gHm0 = zeros(m,n);

%% constants
% acceleration due to gravity [m/s2]
g = 9.81; 

c1 = 1.65; c2 = 4.75;% probabilistic design
% landward-side slope
tan_alpha = 1/4; sin_alpha = sin(atan(1/4)); cos_alpha = cos(atan(1/4));

% coefficient derived from regression analysis of van Gent's data
cAh = 1.097; cAu = 0.8755;


%% calculations

    % wave steepness
        s0 = 2*pi/g*Hm0/(Tm10^2);
    % surf similarity parameter xi_0
        xi0 = tan_alpha/(sqrt(s0));      
        
    % 2% wave run-up
        Ru2per = c1*xi0*Hm0;

  for i = 1:n
            
        % crest freeboard Rc [m] derived from q
        Rc = 1/(-c2)*Hm0*xi0*log(q(i)/0.067/xi0*sqrt(tan_alpha/(g*(Hm0^3))));
        
        % probability of overtopping Pov
        Povt = exp(-((sqrt(-log(0.02))*Rc/Ru2per)^2));
        
        % scale factor
        a = 0.84*Tm*q(i)/Povt;
        
        
        for j = 1:m

            % exceedance probability PV of an overtopping volume per wave
            PV(j,i) = 1 - exp(-((V(j)/a)^0.75));

            % overtopping probability Povx associated with volume V
            Povx(j,i) = (1 - PV(j,i))*Povt;

            % freeboard associated with volume V
            Rux(j,i) = Ru2per*sqrt(log(Povx(j,i))/log(0.02));

            % water-layer thickness at the seaward crest edge hA2%
            hA2_Hm0(j,i) = cAh*sin_alpha*V(j)/(Rux(j,i) - Rc);
            % flow velocity  at the seaward crest edge uA2%
            uA2_gHm0(j,i) = cAu*cos_alpha*sqrt(g*V(j)/sin_alpha/Hm0);

        end

  end


%% figure 1 showing flow depth
 figure1 = figure('Name','Flow depth hA2% vs. overtopping volume');
    set(figure1,'PaperUnits','points');

    xSize = 320; ySize = 180;

    % additional coordinates to locate the figure on A4-paper
    xLeft = (597-xSize)/2; yTop = (845-ySize)/2;

    % set the position and size of the figure on the paper to the desired
    % values
    set(figure1,'PaperPosition', [xLeft yTop xSize ySize]);

    % reset the size and position of the figure window on the computer screen
    set(figure1,'Position', [xLeft yTop xSize*2 ySize*2]);

    x = 45/xSize; y = 40/ySize; 

    % Figure dimensions are 142 pt wide and 106.3 pt high
    width = 220/xSize; height = 127/ySize;

    % Create axes
    axes1 = axes('Parent', figure1, 'position', [x y width height]);
    set(axes1,'XMinorGrid','off');

    % Create xlabel
    xlabel('V [m^3/m]');
    % Create ylabel
    ylabel('h_{A,2%} [m]');

    % X-limits of the axes
    xlim(axes1,[0 6]);
    % Y-limits of the axes
    ylim(axes1,[0 0.5]);
    
    box(axes1,'on');
    hold(axes1,'all');
    
% Flowdike test
plot1 = plot(V,  hA2_Hm0(:,1),'Parent',axes1,'LineStyle','none','Color',[0 0 0]);
set(plot1,'Marker','o','DisplayName','10 l/s per m');
plot2 = plot(V,  hA2_Hm0(:,2),'Parent',axes1,'LineStyle','none','Color',[0 0 0]);
set(plot2,'Marker','square','DisplayName','20 l/s per m');
plot3 = plot(V,  hA2_Hm0(:,3),'Parent',axes1,'LineStyle','none','Color',[0 0 0]);
set(plot3,'Marker','x','DisplayName','40 l/s per m');
plot4 = plot(V,  hA2_Hm0(:,4),'Parent',axes1,'LineStyle','none','Color',[0 0 0]);
set(plot4,'Marker','^','DisplayName','80 l/s per m');
plot5 = plot(V,  hA2_Hm0(:,5),'Parent',axes1,'LineStyle','none','Color',[0 0 0]);
set(plot5,'Marker','+','DisplayName','100 l/s per m');


% Create legend
    legend1 = legend(axes1,'show');
    set(legend1,'Location','EastOutside');

% print figure as an eps file    
%     print('-depsc','-tiff','-r600', 'hA2_FDvsTrung'); 
    
 % figure 2 linear relation
figure2 = figure('Name','Flow velocity uA2% vs. overtopping volume');
    set(figure2,'PaperUnits','points');

    % set the position and size of the figure on the paper to the desired
    % values
    set(figure2,'PaperPosition', [xLeft yTop xSize ySize]);

    % reset the size and position of the figure window on the computer screen
    set(figure2,'Position', [xLeft yTop xSize*2 ySize*2]);

    % Create axes
    axes2 = axes('Parent', figure2, 'position', [x y width height]);
    set(axes2,'XMinorGrid','off');

    % Create xlabel
    xlabel('V [m^3/m]');
    % Create ylabel
    ylabel('u_{A,2%} [m/s]');

    % X-limits of the axes
    xlim(axes2,[0 6]);
    % Y-limits of the axes
    ylim(axes2,[0 10]);
    
    box(axes2,'on');
    hold(axes2,'all');
    
    % Flowdike test
plot7 = plot(V, uA2_gHm0(:,1),'Parent',axes2,'LineStyle','none','Color',[0 0 0]);
set(plot7,'Marker','o','DisplayName','10 l/s per m');
plot8 = plot(V,  uA2_gHm0(:,2),'Parent',axes2,'LineStyle','none','Color',[0 0 0]);
set(plot8,'Marker','square','DisplayName','20 l/s per m');
plot9 = plot(V,  uA2_gHm0(:,3),'Parent',axes2,'LineStyle','none','Color',[0 0 0]);
set(plot9,'Marker','x','DisplayName','40 l/s per m');
plot10 = plot(V,  uA2_gHm0(:,4),'Parent',axes2,'LineStyle','none','Color',[0 0 0]);
set(plot10,'Marker','^','DisplayName','80 l/s per m');
plot11 = plot(V,  uA2_gHm0(:,5),'Parent',axes2,'LineStyle','none','Color',[0 0 0]);
set(plot11,'Marker','+','DisplayName','100 l/s per m');


% Create legend
    legend2 = legend(axes2,'show');
    set(legend2,'Location','EastOutside');

% print figure as an eps file    
%     print('-depsc','-tiff','-r600', 'uA2_FDvsTrung'); 
    