%% Initialization
close all
clear all
clc

u_TL1yC65 = dlmread('u_TL1yC65.txt');
u_TL3yC65 = dlmread('u_TL3yC65.txt');
u_TT2yC65 = dlmread('u_TT2yC65.txt');
u_TT3yC65 = dlmread('u_TT3yC65.txt');


h_TT2yC65 = dlmread('h_TT2yC65.txt');
h_TT3yC65 = dlmread('h_TT3yC65.txt');

%dataFD = dlmread('uh_FD.txt');

Hm0 = 1.5; % wave height
Tp = 6; % peak period
Tm = Tp/1.15; 
Tm10 = Tp/1.1;

% mean overtopping discharges used for the simulator [m3/m]
%q = [0.01 0.02 0.04 0.08 0.1];
%n = length(q);
q = 0.04;

% overtopping volumes used for hydraulic measurement with the simulator
V = [0.5 1 1.5 2 2.5 3 3.5 4 4.5 5];
m = length(V);

    PV = zeros(m,1);
    
    Povx = zeros(m,1);
    
    Rux = zeros(m,1);
    
    % at the seaward crest edge
    hA2 = zeros(m,1); uA2 = zeros(m,1);
    
    % at the landward crest edge
    hB2 = zeros(m,1); uB2 = zeros(m,1);
    
    % at yC = 3.5 m
    hyC = zeros(m,1); uyC = zeros(m,1);

%% constants
% acceleration due to gravity [m/s2]
g = 9.81; 

% coefficients in calculating Ru2% and q wrt probabilistic design
c1 = 1.65; c2 = 4.75;

% landward-side slope
tan_alpha = 1/4; sin_alpha = sin(atan(1/4)); cos_alpha = cos(atan(1/4));

% landward-side slope
tan_beta = 1/3; sin_beta = sin(atan(tan_beta));

% coefficient at the seaward edge crest
cAh = 1.097; cAu = 0.8755;

% coefficient on the crest
     bBh = 1; cBh = 0.0504;
     bBu = 1; cBu = 0.03571;
     
% coefficient on the landward-side slope
    aCh = 0.4023; bCh = 0.0001295; cCh = 0.001339; % R-square = 0.611
    aCu = 0.9229; bCu = 0.01854; cCu = 0.8255; % R-square = 0.6784 
    fCu = 0.2; fCh = fCu;  % friction coefficients

% crest width
B = 1.5; 

% position on the landward-side slope
sC = 6.5; 

%% calculations

    % wave steepness
        s0 = 2*pi/g*Hm0/(Tm10^2);
    % surf similarity parameter xi_0
        xi0 = tan_alpha/(sqrt(s0));      
        
    % 2% wave run-up
        Ru2per = c1*xi0*Hm0;

  
            
        % crest freeboard Rc [m] derived from q
        Rc = 1/(-c2)*Hm0*xi0*log(q/0.067/xi0*sqrt(tan_alpha/(g*(Hm0^3))));
        
        % probability of overtopping Pov
        Povt = exp(-((sqrt(-log(0.02))*Rc/Ru2per)^2));
        
        % scale factor
        a = 0.84*Tm*q/Povt;
        
        
        for j = 1:m

            % exceedance probability PV of an overtopping volume per wave
            PV(j) = 1 - exp(-((V(j)/a)^0.75));

            % overtopping probability Povx associated with volume V
            Povx(j) = (1 - PV(j))*Povt;

            % freeboard associated with volume V
            Rux(j) = Ru2per*sqrt(log(Povx(j))/log(0.02));

            % water-layer thickness at the seaward crest edge hA2%
            hA2(j) = cAh*sin_alpha*V(j)/(Rux(j) - Rc);
            % flow velocity  at the seaward crest edge uA2%
            uA2(j) = cAu*cos_alpha*sqrt(g*V(j)/sin_alpha/Hm0);
            
            % at the landward crest edge xB = B
            hB2(j) = (bBh - cBh*B/Hm0)*hA2(j);
            uB2(j) = (bBu - cBu*B/Hm0)*uA2(j);
            
            % at the position yC = 3.5 m
            hyC(j) = (aCh*hB2(j) - bCh*sC/Hm0 + cCh)*(1+fCh);
            uyC(j) = (aCu*uB2(j) + bCu*sC/Hm0 + cCu)*(1-fCu);

        end


%% figure 1 showing flow depth
 figure1 = figure('Name','Flow depth hyC2% vs. overtopping volume');
    set(figure1,'PaperUnits','points');

    xSize = 320; ySize = 190;

    % additional coordinates to locate the figure on A4-paper
    xLeft = (597-xSize)/2; yTop = (845-ySize)/2;

    % set the position and size of the figure on the paper to the desired
    % values
    set(figure1,'PaperPosition', [xLeft yTop xSize ySize]);

    % reset the size and position of the figure window on the computer screen
    set(figure1,'Position', [xLeft yTop xSize*2 ySize*2]);

    x = 45/xSize; y = 35/ySize; 

    % Figure dimensions are 142 pt wide and 106.3 pt high
    width = 230/xSize; height = 127/ySize;

    % Create axes
    axes1 = axes('Parent', figure1, 'position', [x y width height]);
    set(axes1,'XMinorGrid','off');

    % Create xlabel
    xlabel('V [m^3/m]');
    % Create ylabel
    ylabel('h_{y_C,2%} [m]');

    % X-limits of the axes
    xlim(axes1,[0 6]);
    % Y-limits of the axes
    ylim(axes1,[0 0.6]);
    
    title1 = title(axes1,'f_C^h = 0.2');
    
    box(axes1,'on');
    hold(axes1,'all');


% Measurement at TL and TT
plot1 = plot(V,  hyC,'Parent',axes1,'LineStyle','-','Color',[0 0 0]);
set(plot1,'Marker','o','DisplayName','40 l/s per m');
% plot2 = plot(h_TL1yC65(:,2), h_TL1yC65(:,1),'Parent',axes1,'LineStyle','none','Color',[0 0 0]);
% set(plot2,'Marker','square','DisplayName','TL1, y_C 6.5 m');
% plot3 = plot(h_TL3yC65(:,2), h_TL3yC65(:,1),'Parent',axes1,'LineStyle','none','Color',[0 0 0]);
% set(plot3,'Marker','x','DisplayName','TL3, y_C 6.5 m');
plot4 = plot(h_TT2yC65(:,2), h_TT2yC65(:,1),'Parent',axes1,'LineStyle','none','Color',[0 0 0]);
set(plot4,'Marker','^','DisplayName','TT2, s_C 6.5 m');
plot5 = plot(h_TT3yC65(:,2), h_TT3yC65(:,1),'Parent',axes1,'LineStyle','none','Color',[0 0 0]);
set(plot5,'Marker','+','DisplayName','TT3, s_C 6.5 m');


% Create legend
    legend1 = legend(axes1,'show');
    set(legend1,'Location','EastOutside');

% print figure as an eps file    
     print('-depsc','-tiff','-r600', 'hyC65_TL13TT23f02'); 
    
 % figure 2 linear relation
figure2 = figure('Name','Flow velocity uyC2% vs. overtopping volume');
    set(figure2,'PaperUnits','points');

    % set the position and size of the figure on the paper to the desired
    % values
    set(figure2,'PaperPosition', [xLeft yTop xSize ySize]);

    % reset the size and position of the figure window on the computer screen
    set(figure2,'Position', [xLeft yTop xSize*2 ySize*2]);

    % Create axes
    axes2 = axes('Parent', figure2, 'position', [x y width height]);
    set(axes2,'XMinorGrid','off');

    % Create xlabel
    xlabel('V [m^3/m]');
    % Create ylabel
    ylabel('u_{y_C,2%} [m/s]');

    % X-limits of the axes
    xlim(axes2,[0 6]);
    % Y-limits of the axes
    ylim(axes2,[0 10]);
    
    title2 = title(axes2,'f_C^u = 0.2');
    
    box(axes2,'on');
    hold(axes2,'all');

% Measurement at TL and TT
plot7 = plot(V,  uyC,'Parent',axes2,'LineStyle','-','Color',[0 0 0]);
set(plot7,'Marker','o','DisplayName','40 l/s per m');
plot8 = plot(u_TL1yC65(:,2), u_TL1yC65(:,1),'Parent',axes2,'LineStyle','none','Color',[0 0 0]);
set(plot8,'Marker','square','DisplayName','TL1, s_C 6.5m');
plot9 = plot(u_TL3yC65(:,2), u_TL3yC65(:,1),'Parent',axes2,'LineStyle','none','Color',[0 0 0]);
set(plot9,'Marker','x','DisplayName','TL3, s_C 6.5 m');
plot10 = plot(u_TT2yC65(:,2), u_TT2yC65(:,1),'Parent',axes2,'LineStyle','none','Color',[0 0 0]);
set(plot10,'Marker','^','DisplayName','TT2, s_C 6.5 m');
plot11 = plot(u_TT3yC65(:,2), u_TT3yC65(:,1),'Parent',axes2,'LineStyle','none','Color',[0 0 0]);
set(plot11,'Marker','+','DisplayName','TT3, s_C 6.5 m');


% Create legend
    legend2 = legend(axes2,'show');
    set(legend2,'Location','EastOutside');

% print figure as an eps file    
     print('-depsc','-tiff','-r600', 'uyC65_TL13TT23f02'); 
    