%% Initialization
close all
clear all
clc

u_TL1yC35 = dlmread('u_TL1yC35.txt');

%dataFD = dlmread('uh_FD.txt');

Hm0 = 1.5; % wave height
Tp = 6; % peak period
Tm = Tp/1.15; 
Tm10 = Tp/1.1;

% mean overtopping discharges used for the simulator [m3/m]
%q = [0.01 0.02 0.04 0.08 0.1];
%n = length(q);
q = 0.08;

% overtopping volumes used for hydraulic measurement with the simulator
V = [0.5 1 1.5 2 2.5 3 3.5 4 4.5 5];
m = length(V);

    PV = zeros(m,1);
    
    Povx = zeros(m,1);
    
    Rux = zeros(m,1);
    
    % at the seaward crest edge
    hA2 = zeros(m,1); uA2 = zeros(m,1);
    
    % at the landward crest edge
    hB2 = zeros(m,1); uB2 = zeros(m,1);
    
    % at yC = 3.5 m
    hyC = zeros(m,1); uyC = zeros(m,1);

%% constants
% acceleration due to gravity [m/s2]
g = 9.81; 

% coefficients in calculating Ru2% and q wrt probabilistic design
c1 = 1.65; c2 = 4.75;

% landward-side slope
tan_alpha = 1/4; sin_alpha = sin(atan(1/4)); cos_alpha = cos(atan(1/4));

% landward-side slope
tan_beta = 1/3; sin_beta = sin(atan(tan_beta));

% coefficient at the seaward edge crest
cAh = 1.097; cAu = 0.8755;

% coefficient on the crest
 bBh = 1; cBh = 0.0504;
 bBu = 1; cBu = 0.03571;

% coefficient on the landward-side slope
aCh = 0.4023; bCh = 0.0001295; cCh = 0.001339;
aCu = 0.8255;  bCu = 0.01854; cCu = 0.9229;

% crest width
B = 4; 

% position on the landward-side slope
yC = 3.5; 

%% calculations

    % wave steepness
        s0 = 2*pi/g*Hm0/(Tm10^2);
    % surf similarity parameter xi_0
        xi0 = tan_alpha/(sqrt(s0));      
        
    % 2% wave run-up
        Ru2per = c1*xi0*Hm0;

  
            
        % crest freeboard Rc [m] derived from q
        Rc = 1/(-c2)*Hm0*xi0*log(q/0.067/xi0*sqrt(tan_alpha/(g*(Hm0^3))));
        
        % probability of overtopping Pov
        Povt = exp(-((sqrt(-log(0.02))*Rc/Ru2per)^2));
        
        % scale factor
        a = 0.84*Tm*q/Povt;
        
        
        for j = 1:m

            % exceedance probability PV of an overtopping volume per wave
            PV(j) = 1 - exp(-((V(j)/a)^0.75));

            % overtopping probability Povx associated with volume V
            Povx(j) = (1 - PV(j))*Povt;

            % freeboard associated with volume V
            Rux(j) = Ru2per*sqrt(log(Povx(j))/log(0.02));

            % water-layer thickness at the seaward crest edge hA2%
            hA2(j) = cAh*sin_alpha*V(j)/(Rux(j) - Rc);
            % flow velocity  at the seaward crest edge uA2%
            uA2(j) = cAu*cos_alpha*sqrt(g*V(j)/sin_alpha/Hm0);
            
            % at the landward crest edge xB = B
            hB2(j) = (bBh - cBh*B/Hm0)*hA2(j);
            uB2(j) = (bBu - cBu*B/Hm0)*uA2(j);
            
            % at the position yC = 3.5 m
            hyC(j) = aCh*hB2(j) - bCh*yC/sin_beta/Hm0 + cCh;
            uyC(j) = aCu*uB2(j) + bCu*yC/sin_beta/Hm0 + cCu;

        end




%% figure 1 showing flow depth
 figure1 = figure('Name','Flow depth hyC2% vs. overtopping volume');
    set(figure1,'PaperUnits','points');

    xSize = 320; ySize = 180;

    % additional coordinates to locate the figure on A4-paper
    xLeft = (597-xSize)/2; yTop = (845-ySize)/2;

    % set the position and size of the figure on the paper to the desired
    % values
    set(figure1,'PaperPosition', [xLeft yTop xSize ySize]);

    % reset the size and position of the figure window on the computer screen
    set(figure1,'Position', [xLeft yTop xSize*2 ySize*2]);

    x = 45/xSize; y = 40/ySize; 

    % Figure dimensions are 142 pt wide and 106.3 pt high
    width = 220/xSize; height = 127/ySize;

    % Create axes
    axes1 = axes('Parent', figure1, 'position', [x y width height]);
    set(axes1,'XMinorGrid','off');

    % Create xlabel
    xlabel('V [m^3/m]');
    % Create ylabel
    ylabel('h_{y_C,2%} [m]');

    % X-limits of the axes
    xlim(axes1,[0 6]);
    % Y-limits of the axes
    ylim(axes1,[0 0.5]);
    
    box(axes1,'on');
    hold(axes1,'all');
    
% Flowdike test
plot1 = plot(V,  hyC,'Parent',axes1,'LineStyle','none','Color',[0 0 0]);
set(plot1,'Marker','o','DisplayName','80 l/s per m');
% plot2 = plot(V,  hA2_Hm0(:,2),'Parent',axes1,'LineStyle','none','Color',[0 0 0]);
% set(plot2,'Marker','square','DisplayName','20 l/s per m');
% plot3 = plot(V,  hA2_Hm0(:,3),'Parent',axes1,'LineStyle','none','Color',[0 0 0]);
% set(plot3,'Marker','x','DisplayName','40 l/s per m');
% plot4 = plot(V,  hA2_Hm0(:,4),'Parent',axes1,'LineStyle','none','Color',[0 0 0]);
% set(plot4,'Marker','^','DisplayName','80 l/s per m');
% plot5 = plot(V,  hA2_Hm0(:,5),'Parent',axes1,'LineStyle','none','Color',[0 0 0]);
% set(plot5,'Marker','+','DisplayName','100 l/s per m');


% Create legend
    legend1 = legend(axes1,'show');
    set(legend1,'Location','EastOutside');

% print figure as an eps file    
     print('-depsc','-tiff','-r600', 'hyC35_TL3'); 
    
 % figure 2 linear relation
figure2 = figure('Name','Flow velocity uyC2% vs. overtopping volume');
    set(figure2,'PaperUnits','points');

    % set the position and size of the figure on the paper to the desired
    % values
    set(figure2,'PaperPosition', [xLeft yTop xSize ySize]);

    % reset the size and position of the figure window on the computer screen
    set(figure2,'Position', [xLeft yTop xSize*2 ySize*2]);

    % Create axes
    axes2 = axes('Parent', figure2, 'position', [x y width height]);
    set(axes2,'XMinorGrid','off');

    % Create xlabel
    xlabel('V [m^3/m]');
    % Create ylabel
    ylabel('u_{y_C,2%} [m/s]');

    % X-limits of the axes
    xlim(axes2,[0 6]);
    % Y-limits of the axes
    ylim(axes2,[0 10]);
    
    box(axes2,'on');
    hold(axes2,'all');
    
    % Flowdike test
plot7 = plot(V,  uyC,'Parent',axes2,'LineStyle','none','Color',[0 0 0]);
set(plot7,'Marker','o','DisplayName','80 l/s per m');
plot8 = plot(u_TL1yC35(:,2),  u_TL1yC35(:,1),'Parent',axes2,'LineStyle','none','Color',[0 0 0]);
set(plot8,'Marker','square','DisplayName','TL1, y_C 3.5m');
% plot9 = plot(V,  uA2_gHm0(:,3),'Parent',axes2,'LineStyle','none','Color',[0 0 0]);
% set(plot9,'Marker','x','DisplayName','40 l/s per m');
% plot10 = plot(V,  uA2_gHm0(:,4),'Parent',axes2,'LineStyle','none','Color',[0 0 0]);
% set(plot10,'Marker','^','DisplayName','80 l/s per m');
% plot11 = plot(V,  uA2_gHm0(:,5),'Parent',axes2,'LineStyle','none','Color',[0 0 0]);
% set(plot11,'Marker','+','DisplayName','100 l/s per m');


% Create legend
    legend2 = legend(axes2,'show');
    set(legend2,'Location','EastOutside');

% print figure as an eps file    
     print('-depsc','-tiff','-r600', 'uyC35_TL3'); 
    