%% Initialization
close all
clear all
clc

waveFD = dlmread('waveconditions_FD.txt');

dataFD = dlmread('uh_FD.txt');

[m, n] = size(waveFD);

%Povt = zeros(m,1); a = zeros(m,1); Vovt = zeros(m,1);

% flow depth proposed by Trung
hA_Tr = zeros(m,1);

uA_Tr = zeros(m,1);

hA_Hm0_FD = zeros(m,1);

uA_gHm0_FD = zeros(m,1);

RuRc_Hm0 = zeros(m,1);

%% constants
% acceleration due to gravity [m/s2]
g = 9.81; 

c1 = 4.75; c2 = 1.65;% probabilistic design
% landward-side slope
tan_alphaFD = 1/3; sin_alphaFD = sin(atan(1/3)); cos_alphaFD = cos(atan(1/3));

% coefficient derived from regression analysis of van Gent's data
cAh = 0.872; cAu = 0.887;

% converting Tm-1,0 = Tp/1.1 and Tm = Tp/1.15 => Tm = Tm-1,0*(1.1/1.15)
cT = 1.1/1.15;
%% calculations
for i = 1:m
        % wave steepness
        s0 = 2*pi/g*waveFD(i,1)/((waveFD(i,5))^2);
        % surf similarity parameter xi_0
        xi0 = tan_alphaFD/(sqrt(s0));
        % 2% wave run-up
        Ru2per = c2*xi0*waveFD(i,1);
        Povt = exp(-((sqrt(-log(0.02))*waveFD(i,6)/Ru2per)^2));
        q = sqrt(g*((waveFD(i,1))^3))*0.067/(sqrt(tan_alphaFD))*xi0*exp(-c1*waveFD(i,6)/waveFD(i,1)/xi0);
        % Tm = Tm-1,0 as there is no information, normally Tp/Tm = 1.1 ~
        % 1.25
        a = 0.84*cT*waveFD(i,5)*q/Povt;
        Vovt = real(a*((-log(0.02/Povt))^(4/3)));
        % hA,2% / Hm0 and uA,2% / (gHm0)^0.5 computed by Trung
        hA_Tr(i) = Vovt*sin_alphaFD/(Ru2per - waveFD(i,6))/waveFD(i,1);
        
        uA_Tr(i) = cos_alphaFD/waveFD(i,1)*sqrt(Vovt/sin_alphaFD);
        
        % hA,2% / Hm0  and uA,2% / (gHm0)^0.5 of Flowdike
        hA_Hm0_FD(i) = dataFD(i,1)/waveFD(i,1);
        
        uA_gHm0_FD(i) = dataFD(i,2)/sqrt(g*waveFD(i,1));
        
end

% creating data for linear regression analysis

result = [hA_Tr'; hA_Hm0_FD'; uA_Tr'; uA_gHm0_FD']';

save result_FD.txt result -ASCII;

%% figure 1 showing flow depth
 figure1 = figure('Name','Flow depth hA2%/Hm0 of Flowdike vs. computation');
    set(figure1,'PaperUnits','points');

    xSize = 245; ySize = 180;

    % additional coordinates to locate the figure on A4-paper
    xLeft = (597-xSize)/2; yTop = (845-ySize)/2;

    % set the position and size of the figure on the paper to the desired
    % values
    set(figure1,'PaperPosition', [xLeft yTop xSize ySize]);

    % reset the size and position of the figure window on the computer screen
    set(figure1,'Position', [xLeft yTop xSize*2 ySize*2]);

    x = 45/xSize; y = 40/ySize; 

    % Figure dimensions are 142 pt wide and 106.3 pt high
    width = 180/xSize; height = 127/ySize;

    % Create axes
    axes1 = axes('Parent', figure1, 'position', [x y width height]);
    set(axes1,'XMinorGrid','off');

    % Create xlabel
    xlabel('h_{A,2%} / H_{m0} computation');
    % Create ylabel
    ylabel('h_{A,2%} / H_{m0} measurement');

    % X-limits of the axes
    xlim(axes1,[0.05 1]);
    % Y-limits of the axes
    ylim(axes1,[0.05 1]);
    
    box(axes1,'on');
    hold(axes1,'all');
    
% Flowdike test
plot1 = plot(cAh*hA_Tr(1:12),  hA_Hm0_FD(1:12),'Parent',axes1,'LineStyle','none','Color',[0 0 0]);
set(plot1,'Marker','o','DisplayName','FD07');
plot2 = plot(cAh*hA_Tr(13:24),  hA_Hm0_FD(13:24),'Parent',axes1,'LineStyle','none','Color',[0 0 0]);
set(plot2,'Marker','square','DisplayName','FD06');

plot3 = plot([0 1], [0 1],'Parent',axes1);
set(plot3,'Color','Black');


% Create legend
    legend1 = legend(axes1,'FD07','FD06');
    set(legend1,'Location','EastOutside');

% print figure as an eps file    
    print('-depsc','-tiff','-r600', 'hA2_FDvsTrung'); 
    
 % figure 2 linear relation
figure2 = figure('Name','Flow velocity uA2% of FlowDike vs. Trung');
    set(figure2,'PaperUnits','points');

    % set the position and size of the figure on the paper to the desired
    % values
    set(figure2,'PaperPosition', [xLeft yTop xSize ySize]);

    % reset the size and position of the figure window on the computer screen
    set(figure2,'Position', [xLeft yTop xSize*2 ySize*2]);

    % Create axes
    axes2 = axes('Parent', figure2, 'position', [x y width height]);
    set(axes2,'XMinorGrid','off');

    % Create xlabel
    xlabel('u_{A,2%}/(gH_{m0})^{0.5} computation');
    % Create ylabel
    ylabel('u_{A,2%}/(gH_{m0})^{0.5} measurement');

    % X-limits of the axes
    xlim(axes2,[0.2 4]);
    % Y-limits of the axes
    ylim(axes2,[0.2 4]);
    
    box(axes2,'on');
    hold(axes2,'all');
    
    % Flowdike test
plot4 = plot(cAu*uA_Tr(1:12),  uA_gHm0_FD(1:12),'Parent',axes2,'LineStyle','none','Color',[0 0 0]);
set(plot4,'Marker','o','DisplayName','FD07');
plot5 = plot(cAu*uA_Tr(13:24),  uA_gHm0_FD(13:24),'Parent',axes2,'LineStyle','none','Color',[0 0 0]);
set(plot5,'Marker','square','DisplayName','FD06');

plot6 = plot([0 4], [0 4],'Parent',axes2);
set(plot6,'Color','Black');


% Create legend
    legend2 = legend(axes2,'FD07','FD06');
    set(legend2,'Location','EastOutside');

% print figure as an eps file    
    print('-depsc','-tiff','-r600', 'uA2_FDvsTrung'); 
    