%% Initialization
close all
clear all
clc

wave = dlmread('waveconditions_vG.txt');
dataA = dlmread('uhcrestA_vG.txt');
dataB = dlmread('uhcrestB_vG.txt');
dataC = dlmread('uhcrestC_vG.txt');
dataD = dlmread('uhcrestD_vG.txt');

[m, n] = size(wave);

sqRu2perRc_Hm0 = zeros(m,1);

% ratio of u2% to sqrt(gHm0)
u2per_gHm0_A = zeros(m,1);
u2per_gHm0_B = zeros(m,1);
u2per_gHm0_C = zeros(m,1);
u2per_gHm0_D = zeros(m,1);

%% constants
% acceleration due to gravity [m/s2]
g = 9.81; 
% landward-side slope
tan_alpha = 0.25;

%% calculations
for i = 1:m
        % wave steepness
        s0 = 2*pi/g*wave(i,5)/((wave(i,9))^2);
        % surf similarity parameter xi_0
        xi0 = tan_alpha/sqrt(s0);
        % 2% wave run-up
        Ru2per = 1.75*xi0*wave(i,5);
        sqRu2perRc_Hm0(i) = sqrt((Ru2per - wave(i,3))/wave(i,5));
        % P1 channel 8 P2 9 P3 10 P4 11 P5 12
        u2per_gHm0_A(i) = dataA(i,8)/sqrt(g*wave(i,5));
        u2per_gHm0_B(i) = dataB(i,8)/sqrt(g*wave(i,5));
        u2per_gHm0_C(i) = dataC(i,8)/sqrt(g*wave(i,5));
        u2per_gHm0_D(i) = dataD(i,8)/sqrt(g*wave(i,5));
end

%% figure 1 showing flow depth
 figure1 = figure('Name','Flow velocity measured by van Gent');
    set(figure1,'PaperUnits','points');

    xSize = 260; ySize = 170;

    % additional coordinates to locate the figure on A4-paper
    xLeft = (597-xSize)/2; yTop = (845-ySize)/2;

    % set the position and size of the figure on the paper to the desired
    % values
    set(figure1,'PaperPosition', [xLeft yTop xSize ySize]);

    % reset the size and position of the figure window on the computer screen
    set(figure1,'Position', [xLeft yTop xSize*2 ySize*2]);

    x = 40/xSize; y = 30/ySize; 

    % Figure dimensions are 142 pt wide and 106.3 pt high
    width = 196/xSize; height = 127/ySize;

    % Create axes
    axes1 = axes('Parent', figure1, 'position', [x y width height]);
    set(axes1,'XMinorGrid','off');

    % Create xlabel
    xlabel('sqrt((R_u_2_% - R_c) / H_m_0)');
    % Create ylabel
    ylabel('u_2_% / sqrt(g H_m_0)');

    % X-limits of the axes
    xlim(axes1,[0 2]);
    % Y-limits of the axes
    ylim(axes1,[0 2]);
    
    box(axes1,'on');
    hold(axes1,'all');
    
plot5 = plot(sqRu2perRc_Hm0,u2per_gHm0_A,'Parent',axes1,'LineStyle','none','Color',[0 0 0]);
set(plot5,'Marker','o','DisplayName','A');
plot6 = plot(sqRu2perRc_Hm0,u2per_gHm0_B,'Parent',axes1,'LineStyle','none','Color',[0 0 0]);
set(plot6,'Marker','square','DisplayName','B');
plot7 = plot(sqRu2perRc_Hm0,u2per_gHm0_C,'Parent',axes1,'LineStyle','none','Color',[0 0 0]);
set(plot7,'Marker','x','DisplayName','C');
plot8 = plot(sqRu2perRc_Hm0,u2per_gHm0_D,'Parent',axes1,'LineStyle','none','Color',[0 0 0]);
set(plot8,'Marker','^','DisplayName','D');

% Create legend
    legend1 = legend(axes1,'show');
    set(legend1,'Location','EastOutside');

% print figure as an eps file    
    print('-depsc','-tiff','-r600', 'vG_velocityP1');