%% Initialization
close all
clear all
clc

wave = dlmread('waveconditions_vG.txt');
dataA = dlmread('uhcrestA_vG.txt');
dataB = dlmread('uhcrestB_vG.txt');
dataC = dlmread('uhcrestC_vG.txt');
dataD = dlmread('uhcrestD_vG.txt');

% Povt measured by van Gent channel 1
        vG_PovtA = dataA(:,1);
        vG_PovtB = dataB(:,1);
        vG_PovtC = dataC(:,1);
        vG_PovtD = dataD(:,1);

[m, n] = size(wave);

Povt = zeros(m,1);

%% constants
% acceleration due to gravity [m/s2]
g = 9.81; 
% landward-side slope
tan_alpha = 0.25;

%% calculations
for i = 1:m
        % wave steepness
        s0 = 2*pi/g*wave(i,5)/((wave(i,9))^2);
        % surf similarity parameter xi_0
        xi0 = tan_alpha/sqrt(s0);
        % 2% wave run-up
        Ru2per = 1.75*xi0*wave(i,5);
        Povt(i) = exp(-((sqrt(-log(0.02))*wave(i,3)/Ru2per)^2));
             
        
end

%% figure 1 showing flow depth
 figure1 = figure('Name','Overtopping probability measured by van Gent vs. EuroTop07');
    set(figure1,'PaperUnits','points');

    xSize = 240; ySize = 180;

    % additional coordinates to locate the figure on A4-paper
    xLeft = (597-xSize)/2; yTop = (845-ySize)/2;

    % set the position and size of the figure on the paper to the desired
    % values
    set(figure1,'PaperPosition', [xLeft yTop xSize ySize]);

    % reset the size and position of the figure window on the computer screen
    set(figure1,'Position', [xLeft yTop xSize*2 ySize*2]);

    x = 40/xSize; y = 40/ySize; 

    % Figure dimensions are 142 pt wide and 106.3 pt high
    width = 180/xSize; height = 127/ySize;

    % Create axes
    axes1 = axes('Parent', figure1, 'position', [x y width height]);
    set(axes1,'XMinorGrid','off');

    % Create xlabel
    xlabel('P_o_v by van Gent');
    % Create ylabel
    ylabel('P_o_v with EurOTop');

    % X-limits of the axes
    xlim(axes1,[0 1]);
    % Y-limits of the axes
    ylim(axes1,[0 1]);
    
    box(axes1,'on');
    hold(axes1,'all');
    
plot1 = plot(vG_PovtA,Povt,'Parent',axes1,'LineStyle','none','Color',[0 0 0]);
set(plot1,'Marker','o','DisplayName','A');
plot2 = plot(vG_PovtB,Povt,'Parent',axes1,'LineStyle','none','Color',[0 0 0]);
set(plot2,'Marker','square','DisplayName','B');
plot3 = plot(vG_PovtC,Povt,'Parent',axes1,'LineStyle','none','Color',[0 0 0]);
set(plot3,'Marker','x','DisplayName','C');
plot4 = plot(vG_PovtD,Povt,'Parent',axes1,'LineStyle','none','Color',[0 0 0]);
set(plot4,'Marker','^','DisplayName','D');

% Create legend
    legend1 = legend(axes1,'show');
    set(legend1,'Location','EastOutside');

% print figure as an eps file    
    print('-depsc','-tiff','-r600', 'vG_ovtProbability');