%% Initialization
close all
clear all
clc

wave = dlmread('waveconditions_vG.txt');
dataA = dlmread('uhcrestA_vG.txt');
dataB = dlmread('uhcrestB_vG.txt');
dataC = dlmread('uhcrestC_vG.txt');
dataD = dlmread('uhcrestD_vG.txt');

[m, n] = size(wave);

vG_VovtA = zeros(m,1);
vG_VovtB = zeros(m,1);
vG_VovtC = zeros(m,1);
vG_VovtD = zeros(m,1);
% a = zeros(m,1);
% Vovt = zeros(m,1);
Vovt_Hm02 = zeros(m,1);

%% constants
% acceleration due to gravity [m/s2]
g = 9.81; 
% landward-side slope
tan_alpha = 0.25;

%% calculations
for i = 1:m
        % wave steepness
        s0 = 2*pi/g*wave(i,5)/((wave(i,9))^2);
        % surf similarity parameter xi_0
        xi0 = tan_alpha/sqrt(s0);
        % 2% wave run-up
        Ru2per = 1.75*xi0*wave(i,5);
        Povt = exp(-((sqrt(-log(0.02))*wave(i,3)/Ru2per)^2));
        q = sqrt(g*((wave(i,5))^3))*0.067/sqrt(tan_alpha)*xi0*exp(-4.3*wave(i,3)/wave(i,5)/xi0);
        a = 0.84*wave(i,7)*q/Povt;
        Vovt = a*(-log(0.02/Povt))^(4/3);
        Vovt_Hm02(i) = Vovt/(wave(i,5)^2);
        
        % Povt measured by van Gent channel 1
        vG_VovtA(i) = dataA(i,2)/1000/((wave(i,5))^2);
        vG_VovtB(i) = dataB(i,2)/1000/((wave(i,5))^2);
        vG_VovtC(i) = dataC(i,2)/1000/((wave(i,5))^2);
        vG_VovtD(i) = dataD(i,2)/1000/((wave(i,5))^2);
        
end

%% figure 1 showing flow depth
 figure1 = figure('Name','Overtopping volume 2% measured by van Gent vs. EuroTop07');
    set(figure1,'PaperUnits','points');

    xSize = 240; ySize = 180;

    % additional coordinates to locate the figure on A4-paper
    xLeft = (597-xSize)/2; yTop = (845-ySize)/2;

    % set the position and size of the figure on the paper to the desired
    % values
    set(figure1,'PaperPosition', [xLeft yTop xSize ySize]);

    % reset the size and position of the figure window on the computer screen
    set(figure1,'Position', [xLeft yTop xSize*2 ySize*2]);

    x = 40/xSize; y = 40/ySize; 

    % Figure dimensions are 142 pt wide and 106.3 pt high
    width = 180/xSize; height = 127/ySize;

    % Create axes
    axes1 = axes('Parent', figure1, 'position', [x y width height]);
    set(axes1,'XMinorGrid','off');

    % Create xlabel
    xlabel('V_2_% / H_m_0^2 by van Gent');
    % Create ylabel
    ylabel('V_2_% / H_m_0^2 with EurOTop');

    % X-limits of the axes
    xlim(axes1,[0 1.2]);
    % Y-limits of the axes
    ylim(axes1,[0 1.2]);
    
    box(axes1,'on');
    hold(axes1,'all');
    
plot1 = plot(vG_VovtA,  Vovt_Hm02,'Parent',axes1,'LineStyle','none','Color',[0 0 0]);
set(plot1,'Marker','o','DisplayName','A');
plot2 = plot(vG_VovtB,  Vovt_Hm02,'Parent',axes1,'LineStyle','none','Color',[0 0 0]);
set(plot2,'Marker','square','DisplayName','B');
plot3 = plot(vG_VovtC,  Vovt_Hm02,'Parent',axes1,'LineStyle','none','Color',[0 0 0]);
set(plot3,'Marker','x','DisplayName','C');
plot4 = plot(vG_VovtD,  Vovt_Hm02,'Parent',axes1,'LineStyle','none','Color',[0 0 0]);
set(plot4,'Marker','^','DisplayName','D');

% Create legend
    legend1 = legend(axes1,'show');
    set(legend1,'Location','EastOutside');

% print figure as an eps file    
    print('-depsc','-tiff','-r600', 'vG_ovtVolume');